@@ -24,16 +24,22 @@ from mypy_boto3_es.paginator import (
 )
 from mypy_boto3_es.type_defs import (
     AdvancedSecurityOptionsInputTypeDef,
+    AssociatePackageResponseTypeDef,
     CancelElasticsearchServiceSoftwareUpdateResponseTypeDef,
     CognitoOptionsTypeDef,
     CreateElasticsearchDomainResponseTypeDef,
+    CreatePackageResponseTypeDef,
     DeleteElasticsearchDomainResponseTypeDef,
+    DeletePackageResponseTypeDef,
     DescribeElasticsearchDomainConfigResponseTypeDef,
     DescribeElasticsearchDomainResponseTypeDef,
     DescribeElasticsearchDomainsResponseTypeDef,
     DescribeElasticsearchInstanceTypeLimitsResponseTypeDef,
+    DescribePackagesFilterTypeDef,
+    DescribePackagesResponseTypeDef,
     DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef,
     DescribeReservedElasticsearchInstancesResponseTypeDef,
+    DissociatePackageResponseTypeDef,
     DomainEndpointOptionsTypeDef,
     EBSOptionsTypeDef,
     ElasticsearchClusterConfigTypeDef,
@@ -42,11 +48,14 @@ from mypy_boto3_es.type_defs import (
     GetUpgradeHistoryResponseTypeDef,
     GetUpgradeStatusResponseTypeDef,
     ListDomainNamesResponseTypeDef,
+    ListDomainsForPackageResponseTypeDef,
     ListElasticsearchInstanceTypesResponseTypeDef,
     ListElasticsearchVersionsResponseTypeDef,
+    ListPackagesForDomainResponseTypeDef,
     ListTagsResponseTypeDef,
     LogPublishingOptionTypeDef,
     NodeToNodeEncryptionOptionsTypeDef,
+    PackageSourceTypeDef,
     PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef,
     SnapshotOptionsTypeDef,
     StartElasticsearchServiceSoftwareUpdateResponseTypeDef,
@@ -66,8 +75,10 @@ __all__ = ("ElasticsearchServiceClient",)
 
 
 class Exceptions:
+    AccessDeniedException: Type[Boto3ClientError]
     BaseException: Type[Boto3ClientError]
     ClientError: Type[Boto3ClientError]
+    ConflictException: Type[Boto3ClientError]
     DisabledOperationException: Type[Boto3ClientError]
     InternalException: Type[Boto3ClientError]
     InvalidTypeException: Type[Boto3ClientError]
@@ -79,26 +90,31 @@ class Exceptions:
 
 class ElasticsearchServiceClient:
     """
-    [ElasticsearchService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client)
+    [ElasticsearchService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client)
     """
 
     exceptions: Exceptions
 
     def add_tags(self, ARN: str, TagList: List[TagTypeDef]) -> None:
         """
-        [Client.add_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.add_tags)
+        [Client.add_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.add_tags)
+        """
+
+    def associate_package(self, PackageID: str, DomainName: str) -> AssociatePackageResponseTypeDef:
+        """
+        [Client.associate_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.associate_package)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.can_paginate)
         """
 
     def cancel_elasticsearch_service_software_update(
         self, DomainName: str
     ) -> CancelElasticsearchServiceSoftwareUpdateResponseTypeDef:
         """
-        [Client.cancel_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
+        [Client.cancel_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
         """
 
     def create_elasticsearch_domain(
@@ -122,40 +138,56 @@ class ElasticsearchServiceClient:
         AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = None,
     ) -> CreateElasticsearchDomainResponseTypeDef:
         """
-        [Client.create_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
+        [Client.create_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
+        """
+
+    def create_package(
+        self,
+        PackageName: str,
+        PackageType: Literal["TXT-DICTIONARY"],
+        PackageSource: PackageSourceTypeDef,
+        PackageDescription: str = None,
+    ) -> CreatePackageResponseTypeDef:
+        """
+        [Client.create_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.create_package)
         """
 
     def delete_elasticsearch_domain(
         self, DomainName: str
     ) -> DeleteElasticsearchDomainResponseTypeDef:
         """
-        [Client.delete_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
+        [Client.delete_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
         """
 
     def delete_elasticsearch_service_role(self) -> None:
         """
-        [Client.delete_elasticsearch_service_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
+        [Client.delete_elasticsearch_service_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
+        """
+
+    def delete_package(self, PackageID: str) -> DeletePackageResponseTypeDef:
+        """
+        [Client.delete_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.delete_package)
         """
 
     def describe_elasticsearch_domain(
         self, DomainName: str
     ) -> DescribeElasticsearchDomainResponseTypeDef:
         """
-        [Client.describe_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
+        [Client.describe_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
         """
 
     def describe_elasticsearch_domain_config(
         self, DomainName: str
     ) -> DescribeElasticsearchDomainConfigResponseTypeDef:
         """
-        [Client.describe_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
+        [Client.describe_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
         """
 
     def describe_elasticsearch_domains(
         self, DomainNames: List[str]
     ) -> DescribeElasticsearchDomainsResponseTypeDef:
         """
-        [Client.describe_elasticsearch_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
+        [Client.describe_elasticsearch_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
         """
 
     def describe_elasticsearch_instance_type_limits(
@@ -224,7 +256,17 @@ class ElasticsearchServiceClient:
         DomainName: str = None,
     ) -> DescribeElasticsearchInstanceTypeLimitsResponseTypeDef:
         """
-        [Client.describe_elasticsearch_instance_type_limits documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
+        [Client.describe_elasticsearch_instance_type_limits documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
+        """
+
+    def describe_packages(
+        self,
+        Filters: List[DescribePackagesFilterTypeDef] = None,
+        MaxResults: int = None,
+        NextToken: str = None,
+    ) -> DescribePackagesResponseTypeDef:
+        """
+        [Client.describe_packages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.describe_packages)
         """
 
     def describe_reserved_elasticsearch_instance_offerings(
@@ -234,7 +276,7 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef:
         """
-        [Client.describe_reserved_elasticsearch_instance_offerings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
+        [Client.describe_reserved_elasticsearch_instance_offerings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
         """
 
     def describe_reserved_elasticsearch_instances(
@@ -244,7 +286,14 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribeReservedElasticsearchInstancesResponseTypeDef:
         """
-        [Client.describe_reserved_elasticsearch_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
+        [Client.describe_reserved_elasticsearch_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
+        """
+
+    def dissociate_package(
+        self, PackageID: str, DomainName: str
+    ) -> DissociatePackageResponseTypeDef:
+        """
+        [Client.dissociate_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
         """
 
     def generate_presigned_url(
@@ -255,31 +304,38 @@ class ElasticsearchServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
         """
 
     def get_compatible_elasticsearch_versions(
         self, DomainName: str = None
     ) -> GetCompatibleElasticsearchVersionsResponseTypeDef:
         """
-        [Client.get_compatible_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
+        [Client.get_compatible_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
         """
 
     def get_upgrade_history(
         self, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> GetUpgradeHistoryResponseTypeDef:
         """
-        [Client.get_upgrade_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
+        [Client.get_upgrade_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
         """
 
     def get_upgrade_status(self, DomainName: str) -> GetUpgradeStatusResponseTypeDef:
         """
-        [Client.get_upgrade_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
+        [Client.get_upgrade_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
         """
 
     def list_domain_names(self) -> ListDomainNamesResponseTypeDef:
         """
-        [Client.list_domain_names documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
+        [Client.list_domain_names documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
+        """
+
+    def list_domains_for_package(
+        self, PackageID: str, MaxResults: int = None, NextToken: str = None
+    ) -> ListDomainsForPackageResponseTypeDef:
+        """
+        [Client.list_domains_for_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
         """
 
     def list_elasticsearch_instance_types(
@@ -290,19 +346,26 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> ListElasticsearchInstanceTypesResponseTypeDef:
         """
-        [Client.list_elasticsearch_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
+        [Client.list_elasticsearch_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
         """
 
     def list_elasticsearch_versions(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListElasticsearchVersionsResponseTypeDef:
         """
-        [Client.list_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
+        [Client.list_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
+        """
+
+    def list_packages_for_domain(
+        self, DomainName: str, MaxResults: int = None, NextToken: str = None
+    ) -> ListPackagesForDomainResponseTypeDef:
+        """
+        [Client.list_packages_for_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
         """
 
     def list_tags(self, ARN: str) -> ListTagsResponseTypeDef:
         """
-        [Client.list_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.list_tags)
+        [Client.list_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.list_tags)
         """
 
     def purchase_reserved_elasticsearch_instance_offering(
@@ -312,19 +375,19 @@ class ElasticsearchServiceClient:
         InstanceCount: int = None,
     ) -> PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef:
         """
-        [Client.purchase_reserved_elasticsearch_instance_offering documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
+        [Client.purchase_reserved_elasticsearch_instance_offering documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
         """
 
     def remove_tags(self, ARN: str, TagKeys: List[str]) -> None:
         """
-        [Client.remove_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.remove_tags)
+        [Client.remove_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.remove_tags)
         """
 
     def start_elasticsearch_service_software_update(
         self, DomainName: str
     ) -> StartElasticsearchServiceSoftwareUpdateResponseTypeDef:
         """
-        [Client.start_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
+        [Client.start_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
         """
 
     def update_elasticsearch_domain_config(
@@ -345,14 +408,14 @@ class ElasticsearchServiceClient:
         AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = None,
     ) -> UpdateElasticsearchDomainConfigResponseTypeDef:
         """
-        [Client.update_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
+        [Client.update_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
         """
 
     def upgrade_elasticsearch_domain(
         self, DomainName: str, TargetVersion: str, PerformCheckOnly: bool = None
     ) -> UpgradeElasticsearchDomainResponseTypeDef:
         """
-        [Client.upgrade_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
+        [Client.upgrade_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
         """
 
     @overload
@@ -360,7 +423,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["describe_reserved_elasticsearch_instance_offerings"]
     ) -> DescribeReservedElasticsearchInstanceOfferingsPaginator:
         """
-        [Paginator.DescribeReservedElasticsearchInstanceOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
+        [Paginator.DescribeReservedElasticsearchInstanceOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
         """
 
     @overload
@@ -368,7 +431,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["describe_reserved_elasticsearch_instances"]
     ) -> DescribeReservedElasticsearchInstancesPaginator:
         """
-        [Paginator.DescribeReservedElasticsearchInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
+        [Paginator.DescribeReservedElasticsearchInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
         """
 
     @overload
@@ -376,7 +439,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["get_upgrade_history"]
     ) -> GetUpgradeHistoryPaginator:
         """
-        [Paginator.GetUpgradeHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
+        [Paginator.GetUpgradeHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
         """
 
     @overload
@@ -384,7 +447,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["list_elasticsearch_instance_types"]
     ) -> ListElasticsearchInstanceTypesPaginator:
         """
-        [Paginator.ListElasticsearchInstanceTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
+        [Paginator.ListElasticsearchInstanceTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
         """
 
     @overload
@@ -392,5 +455,5 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["list_elasticsearch_versions"]
     ) -> ListElasticsearchVersionsPaginator:
         """
-        [Paginator.ListElasticsearchVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
+        [Paginator.ListElasticsearchVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
         """
