@@ -24,6 +24,9 @@ else:
 __all__ = (
     "MasterUserOptionsTypeDef",
     "AdvancedSecurityOptionsInputTypeDef",
+    "ErrorDetailsTypeDef",
+    "DomainPackageDetailsTypeDef",
+    "AssociatePackageResponseTypeDef",
     "ServiceSoftwareOptionsTypeDef",
     "CancelElasticsearchServiceSoftwareUpdateResponseTypeDef",
     "CognitoOptionsTypeDef",
@@ -39,7 +42,10 @@ __all__ = (
     "VPCDerivedInfoTypeDef",
     "ElasticsearchDomainStatusTypeDef",
     "CreateElasticsearchDomainResponseTypeDef",
+    "PackageDetailsTypeDef",
+    "CreatePackageResponseTypeDef",
     "DeleteElasticsearchDomainResponseTypeDef",
+    "DeletePackageResponseTypeDef",
     "OptionStatusTypeDef",
     "AccessPoliciesStatusTypeDef",
     "AdvancedOptionsStatusTypeDef",
@@ -65,11 +71,14 @@ __all__ = (
     "StorageTypeTypeDef",
     "LimitsTypeDef",
     "DescribeElasticsearchInstanceTypeLimitsResponseTypeDef",
+    "DescribePackagesFilterTypeDef",
+    "DescribePackagesResponseTypeDef",
     "RecurringChargeTypeDef",
     "ReservedElasticsearchInstanceOfferingTypeDef",
     "DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef",
     "ReservedElasticsearchInstanceTypeDef",
     "DescribeReservedElasticsearchInstancesResponseTypeDef",
+    "DissociatePackageResponseTypeDef",
     "CompatibleVersionsMapTypeDef",
     "GetCompatibleElasticsearchVersionsResponseTypeDef",
     "UpgradeStepItemTypeDef",
@@ -78,10 +87,13 @@ __all__ = (
     "GetUpgradeStatusResponseTypeDef",
     "DomainInfoTypeDef",
     "ListDomainNamesResponseTypeDef",
+    "ListDomainsForPackageResponseTypeDef",
     "ListElasticsearchInstanceTypesResponseTypeDef",
     "ListElasticsearchVersionsResponseTypeDef",
+    "ListPackagesForDomainResponseTypeDef",
     "TagTypeDef",
     "ListTagsResponseTypeDef",
+    "PackageSourceTypeDef",
     "PaginatorConfigTypeDef",
     "PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef",
     "StartElasticsearchServiceSoftwareUpdateResponseTypeDef",
@@ -106,6 +118,33 @@ AdvancedSecurityOptionsInputTypeDef = TypedDict(
     total=False,
 )
 
+ErrorDetailsTypeDef = TypedDict(
+    "ErrorDetailsTypeDef", {"ErrorType": str, "ErrorMessage": str}, total=False
+)
+
+DomainPackageDetailsTypeDef = TypedDict(
+    "DomainPackageDetailsTypeDef",
+    {
+        "PackageID": str,
+        "PackageName": str,
+        "PackageType": Literal["TXT-DICTIONARY"],
+        "LastUpdated": datetime,
+        "DomainName": str,
+        "DomainPackageStatus": Literal[
+            "ASSOCIATING", "ASSOCIATION_FAILED", "ACTIVE", "DISSOCIATING", "DISSOCIATION_FAILED"
+        ],
+        "ReferencePath": str,
+        "ErrorDetails": ErrorDetailsTypeDef,
+    },
+    total=False,
+)
+
+AssociatePackageResponseTypeDef = TypedDict(
+    "AssociatePackageResponseTypeDef",
+    {"DomainPackageDetails": DomainPackageDetailsTypeDef},
+    total=False,
+)
+
 ServiceSoftwareOptionsTypeDef = TypedDict(
     "ServiceSoftwareOptionsTypeDef",
     {
@@ -377,12 +416,43 @@ CreateElasticsearchDomainResponseTypeDef = TypedDict(
     total=False,
 )
 
+PackageDetailsTypeDef = TypedDict(
+    "PackageDetailsTypeDef",
+    {
+        "PackageID": str,
+        "PackageName": str,
+        "PackageType": Literal["TXT-DICTIONARY"],
+        "PackageDescription": str,
+        "PackageStatus": Literal[
+            "COPYING",
+            "COPY_FAILED",
+            "VALIDATING",
+            "VALIDATION_FAILED",
+            "AVAILABLE",
+            "DELETING",
+            "DELETED",
+            "DELETE_FAILED",
+        ],
+        "CreatedAt": datetime,
+        "ErrorDetails": ErrorDetailsTypeDef,
+    },
+    total=False,
+)
+
+CreatePackageResponseTypeDef = TypedDict(
+    "CreatePackageResponseTypeDef", {"PackageDetails": PackageDetailsTypeDef}, total=False
+)
+
 DeleteElasticsearchDomainResponseTypeDef = TypedDict(
     "DeleteElasticsearchDomainResponseTypeDef",
     {"DomainStatus": ElasticsearchDomainStatusTypeDef},
     total=False,
 )
 
+DeletePackageResponseTypeDef = TypedDict(
+    "DeletePackageResponseTypeDef", {"PackageDetails": PackageDetailsTypeDef}, total=False
+)
+
 _RequiredOptionStatusTypeDef = TypedDict(
     "_RequiredOptionStatusTypeDef",
     {
@@ -544,6 +614,18 @@ DescribeElasticsearchInstanceTypeLimitsResponseTypeDef = TypedDict(
     total=False,
 )
 
+DescribePackagesFilterTypeDef = TypedDict(
+    "DescribePackagesFilterTypeDef",
+    {"Name": Literal["PackageID", "PackageName", "PackageStatus"], "Value": List[str]},
+    total=False,
+)
+
+DescribePackagesResponseTypeDef = TypedDict(
+    "DescribePackagesResponseTypeDef",
+    {"PackageDetailsList": List[PackageDetailsTypeDef], "NextToken": str},
+    total=False,
+)
+
 RecurringChargeTypeDef = TypedDict(
     "RecurringChargeTypeDef",
     {"RecurringChargeAmount": float, "RecurringChargeFrequency": str},
@@ -723,6 +805,12 @@ DescribeReservedElasticsearchInstancesResponseTypeDef = TypedDict(
     total=False,
 )
 
+DissociatePackageResponseTypeDef = TypedDict(
+    "DissociatePackageResponseTypeDef",
+    {"DomainPackageDetails": DomainPackageDetailsTypeDef},
+    total=False,
+)
+
 CompatibleVersionsMapTypeDef = TypedDict(
     "CompatibleVersionsMapTypeDef", {"SourceVersion": str, "TargetVersions": List[str]}, total=False
 )
@@ -777,6 +865,12 @@ ListDomainNamesResponseTypeDef = TypedDict(
     "ListDomainNamesResponseTypeDef", {"DomainNames": List[DomainInfoTypeDef]}, total=False
 )
 
+ListDomainsForPackageResponseTypeDef = TypedDict(
+    "ListDomainsForPackageResponseTypeDef",
+    {"DomainPackageDetailsList": List[DomainPackageDetailsTypeDef], "NextToken": str},
+    total=False,
+)
+
 ListElasticsearchInstanceTypesResponseTypeDef = TypedDict(
     "ListElasticsearchInstanceTypesResponseTypeDef",
     {
@@ -853,12 +947,22 @@ ListElasticsearchVersionsResponseTypeDef = TypedDict(
     total=False,
 )
 
+ListPackagesForDomainResponseTypeDef = TypedDict(
+    "ListPackagesForDomainResponseTypeDef",
+    {"DomainPackageDetailsList": List[DomainPackageDetailsTypeDef], "NextToken": str},
+    total=False,
+)
+
 TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
 
 ListTagsResponseTypeDef = TypedDict(
     "ListTagsResponseTypeDef", {"TagList": List[TagTypeDef]}, total=False
 )
 
+PackageSourceTypeDef = TypedDict(
+    "PackageSourceTypeDef", {"S3BucketName": str, "S3Key": str}, total=False
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
